| dim,odm-method | R Documentation |
odm objectncol() and nrow() return the number of rows (i.e., features) and columns (i.e., cells), respectively, contained within an odm object. dim() returns an integer vector of length two whose first and second entries, respectively, indicate the number of rows and columns in an odm object.
## S4 method for signature 'odm'
dim(x)
x |
an object of class |
the dimension of the odm object
directories_to_load <- file.path(
system.file("extdata", "highmoi_example", package = "ondisc"),
paste0("gem_group_", c(1, 2))
)
directory_to_write <- tempdir()
# Set data.table threads to 1 to pass CRAN example timing checks.
old_threads <- data.table::setDTthreads(1L)
out_list <- create_odm_from_cellranger(
directories_to_load = directories_to_load,
directory_to_write = directory_to_write,
)
data.table::setDTthreads(old_threads)
gene_odm <- out_list$gene
# return the dimension, number of rows, and number of columns
dim(gene_odm)
nrow(gene_odm)
ncol(gene_odm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.